@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use Moose;
 use namespace::autoclean;
@@ -59,7 +59,7 @@ Dist::Zilla::PluginBundle::Code - a dynamic bundle
 
 =head1 VERSION
 
-Version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -143,7 +143,7 @@ This is free software, licensed under:
 
 =head1 SEE ALSO
 
-L<Dist::Zilla>, L<lib>
+L<Dist::Zilla>, L<Dist::Zilla::Role::PluginBundle>
 
 =cut
 
