@@ -31,15 +31,13 @@ sub configure {
             $moniker,
             $plugin_name,
             {
-                $code => [
-                    sub {
-                        my ($self) = @_;
-                        $self->log($input);
-                        $RESULT = $input * $input;
-                        my @modules = grep { $_->name =~ m{ ^ lib/file- [13] .* [.] pm }xsm } @{ $self->zilla->files };
-                        return \@modules;
-                    },
-                ],
+                $code => sub {
+                    my ($self) = @_;
+                    $self->log($input);
+                    $RESULT = $input * $input;
+                    my @modules = grep { $_->name =~ m{ ^ lib/file- [13] .* [.] pm }xsm } @{ $self->zilla->files };
+                    return \@modules;
+                },
             },
         ],
         [
